==> Pyautomators-1.6.7.tar.gz: Pyautomators-1.6.7/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup,find_packages

setup(name='Pyautomators',
      version='1.6.7',
      url='',
      license='MIT',
      author='Kaue_Bonfim',
      author_email='koliveirab@indracompany.com',
      description='Biblioteca de automação para geracao completa de ambientacao de testes',
      packages=['Pyautomators',
                  'Pyautomators.BDT',
                  'Pyautomators.Graphic_actions',
                  'Pyautomators.BDT.api',
                  'Pyautomators.BDT.compat',
                  'Pyautomators.BDT.contrib',
                  'Pyautomators.BDT.formatter',
      		'Pyautomators.BDT.reporter'],
	install_requires=['webdriver-manager',
                  "pytesseract",
                  "pillow",
                  "pyyaml",
                  "peewee",
                  "pyautogui",
                  "assertpy",
                  "cx_Oracle",
                  "selenium",
                  "numpy",
                  "PyMySQL==0.7.8",
                  "opencv-python",
                  "Appium-Python-Client",
                  "behave2cucumber",
                  "python-jenkins",
                  "django",
                  "pandas",
                  "pymongo",
                  "beautifulsoup4",
                  "nltk",
                  "TestLink-API-Python-client",
                  "sqlalchemy",
                  "argparse",
                  'docker',
                  "parse >= 1.8.2",
                  "parse_type >= 0.4.2",
                  "six >= 1.11",
                  "argparse; python_version < '2.7'",
                  "importlib; python_version < '2.7'",
                  "ordereddict; python_version < '2.7'",
                  "traceback2; python_version < '3.0'",
                  "enum34; python_version < '3.4'",
                  "lackey"],
      zip_safe=True)

==> Pyautomators-1.6.8.tar.gz: Pyautomators-1.6.8/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup,find_packages

setup(name='Pyautomators',
      version='1.6.8',
      url='',
      license='MIT',
      author='Kaue_Bonfim',
      author_email='koliveirab@indracompany.com',
      description='Biblioteca de automação para geracao completa de ambientacao de testes',
      packages=['Pyautomators',
                  'Pyautomators.BDT',
                  'Pyautomators.Graphic_actions',
                  'Pyautomators.BDT.api',
                  'Pyautomators.BDT.compat',
                  'Pyautomators.BDT.contrib',
                  'Pyautomators.BDT.formatter',
      		'Pyautomators.BDT.reporter'],
	install_requires=["python-docx",
	             'webdriver-manager',
                  "pytesseract",
                  "pillow",
                  "pyyaml",
                  "peewee",
                  "pyautogui",
                  "assertpy",
                  "cx_Oracle",
                  "selenium",
                  "numpy",
                  "PyMySQL==0.7.8",
                  "opencv-python",
                  "Appium-Python-Client",
                  "behave2cucumber",
                  "python-jenkins",
                  "django",
                  "pandas",
                  "pymongo",
                  "beautifulsoup4",
                  "nltk",
                  "TestLink-API-Python-client",
                  "sqlalchemy",
                  "argparse",
                  'docker',
                  "parse >= 1.8.2",
                  "parse_type >= 0.4.2",
                  "six >= 1.11",
                  "argparse; python_version < '2.7'",
                  "importlib; python_version < '2.7'",
                  "ordereddict; python_version < '2.7'",
                  "traceback2; python_version < '3.0'",
                  "enum34; python_version < '3.4'",
                  "lackey"],
      zip_safe=True)
